@@ -2,7 +2,7 @@ from decimal import Decimal
 from django.db.models import QuerySet, Sum
 
 
-def sum_queryset(qs: QuerySet, key: str = 'amount', default: Decimal = Decimal(0)) -> Decimal:
+def sum_queryset(qs: QuerySet, key: str = "amount", default: Decimal = Decimal(0)) -> Decimal:
     """
     Returns aggregate sum of queryset 'amount' field.
     :param qs: QuerySet
@@ -10,5 +10,5 @@ def sum_queryset(qs: QuerySet, key: str = 'amount', default: Decimal = Decimal(0
     :param default: Default value if no results
     :return: Sum of 'amount' field values (coalesced 0 if None)
     """
-    res = qs.aggregate(b=Sum(key))['b']
+    res = qs.aggregate(b=Sum(key))["b"]
     return default if res is None else res
